package com.ruoyi.project.cui.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.common.domain.DataEntity;
import com.ruoyi.project.cui.domain.TPvessel;

/**
 * 容器清单Mapper接口
 * 
 * @author ruoyi
 * @date 2020-12-03
 */
public interface TPvesselMapper 
{
    /**
     * 查询容器清单
     * 
     * @param id 容器清单ID
     * @return 容器清单
     */
    public TPvessel selectTPvesselById(Long id);

    /**
     * 查询容器清单列表
     * 
     * @param tPvessel 容器清单
     * @return 容器清单集合
     */
    @DataScope(deptAlias = "d")
    public List<TPvessel> selectTPvesselList(TPvessel tPvessel);

    /**
     * 新增容器清单
     * 
     * @param tPvessel 容器清单
     * @return 结果
     */
    public int insertTPvessel(TPvessel tPvessel);

    /**
     * 修改容器清单
     * 
     * @param tPvessel 容器清单
     * @return 结果
     */
    public int updateTPvessel(TPvessel tPvessel);

    /**
     * 删除容器清单
     * 
     * @param id 容器清单ID
     * @return 结果
     */
    public int deleteTPvesselById(Long id);

    /**
     * 批量删除容器清单
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTPvesselByIds(Long[] ids);

    List<DataEntity> selectRiskData(Map param);

    List<DataEntity> selectStatusData(Map param);
}
